@@ -1,7 +1,7 @@
 package Device::Cdio::Track;
 require 5.8.6;
 #
-#    $Id: Track.pm,v 1.7 2006/02/13 02:20:20 rocky Exp $
+#    $Id: Track.pm,v 1.9 2006/02/26 04:03:29 rocky Exp $
 #
 #    Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
 #
@@ -64,7 +64,7 @@ sub new {
 
   my $self = {};
   
-  if ($track !~ m/^\d+$/) {
+  if ($track !~ m{\A\d+\Z}) {
       print "*** Expecting track to be an integer; got '$track'\n";
       return undef;
   } elsif ($track < 0 || $track > 200) {
@@ -129,9 +129,9 @@ sub get_copy_permit {
 
 =head2 get_format
 
-get_format()->format
+get_format()->$format
        
-Get the format (audio, mode2, mode1) of track. 
+Get the format (e.g. 'audio', 'mode2', 'mode1') of track. 
 
 =cut
 
@@ -257,6 +257,24 @@ sub is_track_green {
     return perlcdio::is_track_green($self->{device}, $self->{track});
 }
 
+=pod
+
+=head2 set_track
+
+set_track(track_num)
+
+Set a new track number.
+
+=cut 
+
+sub set_track {
+    my($self,@p) = @_;
+    my($track_num, @args) = _rearrange(['TRACK'], @p);
+    return undef if _extra_args(@args);
+    $self->{track} = $track_num;
+    return $self;
+}
+
 1; # Magic true value required at the end of a module
 
 __END__
